pub struct BoundWriteMapping { /* private fields */ }Expand description
Sole-writer witness that owns its consumed active mapping.
Like the ActiveWriter it owns, a bound writer may move between threads
but cannot be shared between them:
ⓘ
use native_ipc::binding::BoundWriteMapping;
use native_ipc::core::mapping::WriterRegion;
fn assert_sync<T: Sync>() {}
assert_sync::<WriterRegion<BoundWriteMapping>>();Implementations
Sourceimpl BoundWriteMapping
impl BoundWriteMapping
Sourcepub fn into_active(self) -> ActiveWriter
pub fn into_active(self) -> ActiveWriter
Releases the witness and returns the owned active mapping unchanged.