pub enum GrowthPolicy {
Fixed,
ReplaceBeforeShare {
maximum_len: usize,
},
}Expand description
Capacity policy while a region is still private and quiescent.
Variants
Fixed
Mapping size is fixed at allocation.
Growth replaces the private mapping up to an inclusive logical limit.