pub enum WriterOwner {
Creator,
Peer,
}Expand description
Endpoint that will retain the sole writable mapping after transfer.
Variants
Creator
The process creating and transferring the region remains the writer.
Peer
The authenticated peer becomes the sole writer.