pub const fn native_memory_capabilities() -> NativeMemoryCapabilitiesExpand description
Reports the native memory behavior selected for this target.
pub const fn native_memory_capabilities() -> NativeMemoryCapabilitiesReports the native memory behavior selected for this target.