pub struct ActiveLeaseFacts { /* private fields */ }Expand description
Bounded counters for active mappings that still retain a session lease.
Implementations
Sourceimpl ActiveLeaseFacts
impl ActiveLeaseFacts
Sourcepub const fn consistency(self) -> LeaseFactsConsistency
pub const fn consistency(self) -> LeaseFactsConsistency
Whether the two independently observed atomic counters are exact.